// Copyright (c) 2019, the Dart project authors.  Please see the AUTHORS file
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.

/// String operations based on characters (Unicode grapheme clusters).
library;

export 'src/characters.dart';
export 'src/extensions.dart';
